@@ -55,6 +55,27 @@ sub my_read
     $buf;
 }
 
+BEGIN {
+    my $f = ($] >= 5.008) ? <<'EOT' : <<'EOT';
+        sub with_io_string (&$) {
+	    open(my $fh, "<", \$_[1]);
+	    local $_ = $fh;
+	    &{$_[0]};
+	}
+EOT
+	sub with_io_string (&$) {
+	    require IO::String;
+	    local $_ = IO::String->new($_[1]);
+	    &{$_[0]};
+	    $_->close;
+	}
+EOT
+
+    #print $f;
+    eval $f;
+    die $@ if $@;
+}
+
 sub process_file
 {
     my($info, $fh, $cnf) = @_;
@@ -115,17 +136,24 @@ sub process_chunk
 	}
 
 	if (1) {
+	    my %comp_id_lookup = ( 1 => "Y",
+				   2 => "Cb",
+				   3 => "Cr",
+				   82 => "R",
+				   71 => "G",
+				   66 => "B" );
 	    while (length($data)) {
 		my($comp_id, $hv, $qtable) =
 		    unpack("CCC", substr($data, 0, 3, ""));
-		$comp_id = { 1 => "Y",
-			     2 => "Cb",
-			     3 => "Cr",
-			     82 => "R",
-			     71 => "G",
-			     66 => "B",
-			   }->{$comp_id} || $comp_id;
-		$info->push_info(0, "ColorComponents", [$comp_id, $hv, $qtable]);
+		my $horiz_sf = $hv >> 4 & 0x0f;
+		my $vert_sf = $hv & 0x0f;
+		$comp_id = $comp_id_lookup{$comp_id} || $comp_id;
+		$info->push_info($img_no, "ColorComponents",  [$comp_id, $hv, $qtable]);
+		$info->push_info($img_no, "ColorComponentsDecoded", 
+				 { ComponentIdentifier => $comp_id, 
+				   HorizontalSamplingFactor => $horiz_sf, 
+				   VerticalSamplingFactor => $vert_sf, 
+				   QuantizationTableDesignator => $qtable } );
 	    }
 	}
     }
@@ -198,9 +226,9 @@ sub process_app0_jfxx
 
     if ($code == 0x10) {
 	eval {
-	    require IO::String;
-	    my $thumb_fh = IO::String->new($data);
-	    _process_file($info, $thumb_fh, 1);
+	    with_io_string {
+		_process_file($info, $_, 1);
+	    } $data;
 	};
 	$info->push_info(1, "error" => $@) if $@;
     }
@@ -233,14 +261,22 @@ sub process_app1_exif
 	    my $jdata = substr($data, $ipos, $ilen);
 	    #$info->push_info($i, "JPEGImage" => $jdata);
 
-	    require IO::String;
-	    my $fh = IO::String->new($jdata);
-	    _process_file($info, $fh, $i);
+	    with_io_string {
+		_process_file($info, $_, $i);
+	    } $jdata;
 	}
 
 	# Turn XResolution/YResolution into 'resolution'
 	my($xres) = $info->get_info($i, "XResolution", 1);
 	my($yres) = $info->get_info($i, "YResolution", 1);
+
+	# Samsung Digimax 200 is a totally confused camera that
+	# puts rational numbers with 0 as denominator and they
+	# also seem to not understand what resolution means.
+	for ($xres, $yres) {
+	    $_ += 0 if ref($_) eq "Image::TIFF::Rational";
+	}
+
 	my($unit) = $info->get_info($i, "ResolutionUnit", 1);
 	my $res = "1/1";  # default;
 	if ($xres && $yres) {
