@@ -1,6 +1,6 @@
 package Image::Info::PNG;
 
-# Copyright 1999-200, Gisle Aas.
+# Copyright 1999-2000, Gisle Aas.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -19,6 +19,13 @@ key.
 
 use strict;
 
+# Test for Compress::Zlib (for reading zTXt chunks)
+my $have_zlib = 0;
+eval {
+    require Compress::Zlib;
+    $have_zlib++;
+};
+
 sub my_read
 {
     my($source, $len) = @_;
@@ -128,6 +135,15 @@ sub process_file
 	    # other key we might generate
 	    $info->push_info(0, $key, $val);
 	}
+	elsif ($type eq "zTXt" && $have_zlib) {
+		my($key, $val) = split(/\0/, $data, 2);
+		my($method,$ctext) = split(//, $val, 2);
+		if ($method == 0) {
+		    $info->push_info(0, $key, Compress::Zlib::uncompress($ctext));
+		} else {
+		    $info->push_info(0, "Chunk-$type" => $data);
+		}
+	}
 	elsif ($type eq "tIME" && $len == 7) {
 	    $info->push_info(0, "LastModificationTime",
 			     sprintf("%04d-%02d-%02d %02d:%02d:%02d",
