@@ -325,6 +325,7 @@ my %makernotes = (
     "Canon Canon EOS 10D"            => [0, 'Canon', \%canon_tags],
     "Canon Canon EOS D30"            => [0, 'Canon', \%canon_tags],
     "Canon Canon EOS D60"            => [0, 'Canon', \%canon_tags],
+    "Canon Canon EOS DIGITAL REBEL"  => [0, 'Canon', \%canon_tags],
     "Canon Canon DIGITAL IXUS"       => [0, 'Canon', \%canon_tags],
     "Canon Canon DIGITAL IXUS 300"   => [0, 'Canon', \%canon_tags],
     "Canon Canon PowerShot G1"       => [0, 'Canon', \%canon_tags],
@@ -369,7 +370,6 @@ my %exif_tags = (
 		# 9 .. 255 reserved
 	      },
     0x8824 => "SpectralSensitivity",
-    0x8825 => "GPSInfo",
     0x8827 => "ISOSpeedRatings",
     0x8828 => "OECF",
     0x9000 => "ExifVersion",
@@ -542,6 +542,40 @@ my %exif_tags = (
     0xA420 => "ImageUniqueID",
 );
 
+my %gps_tags = (
+    0x0000 => 'GPSVersionID',
+    0x0001 => 'GPSLatitudeRef',
+    0x0002 => 'GPSLatitude',
+    0x0003 => 'GPSLongitudeRef',
+    0x0004 => 'GPSLongitude',
+    0x0005 => 'GPSAltitudeRef',
+    0x0006 => 'GPSAltitude',
+    0x0007 => 'GPSTimeStamp',
+    0x0008 => 'GPSSatellites',
+    0x0009 => 'GPSStatus',
+    0x000A => 'GPSMeasureMode',
+    0x000B => 'GPSDOP',
+    0x000C => 'GPSSpeedRef',
+    0x000D => 'GPSSpeed',
+    0x000E => 'GPSTrackRef',
+    0x000F => 'GPSTrack',
+    0x0010 => 'GPSImgDirectionRef',
+    0x0011 => 'GPSImgDirection',
+    0x0012 => 'GPSMapDatum',
+    0x0013 => 'GPSDestLatitudeRef',
+    0x0014 => 'GPSDestLatitude',
+    0x0015 => 'GPSDestLongitudeRef',
+    0x0016 => 'GPSDestLongitude',
+    0x0017 => 'GPSDestBearingRef',
+    0x0018 => 'GPSDestBearing',
+    0x0019 => 'GPSDestDistanceRef',
+    0x001A => 'GPSDestDistance',
+    0x001B => 'GPSProcessingMethod',
+    0x001C => 'GPSAreaInformation',
+    0x001D => 'GPSDateStamp',
+    0x001E => 'GPSDifferential',
+);
+
 my %tiff_tags = (
   254   => { __TAG__ => "NewSubfileType",
 	     1 => "ReducedResolution",
@@ -627,6 +661,9 @@ my %tiff_tags = (
   34665 => { __TAG__ => "ExifOffset",
 	     __SUBIFD__ => \%exif_tags,
 	   },
+  34853 => { __TAG__ => "GPSInfo",
+             __SUBIFD__ => \%gps_tags,
+	   },
 );
 
 
